<?php

namespace Drupal\denormalizer\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Denormalizer Settings Form.
 */
class DenormalizerSettingsForm extends ConfigFormBase {

  /**
   * The entity bundle service.
   *
   * @var \Drupal\Core\Entity\EntityTypeBundleInfoInterface
   */
  protected $bundleInfo;

  /**
   * DenormalizerSettingsForm constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   Config factory.
   * @param \Drupal\Core\Entity\EntityTypeBundleInfoInterface $bundleInfo
   *   The bundle info.
   */
  public function __construct(ConfigFactoryInterface $configFactory, EntityTypeBundleInfoInterface $bundleInfo) {
    parent::__construct($configFactory);
    $this->bundleInfo = $bundleInfo;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.bundle.info')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'denormalizer_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['denormalizer.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('denormalizer.settings');

    $form['cron_enabled'] = [
      '#title' => $this->t('Run on cron?'),
      '#type' => 'checkbox',
      '#default_value' => $config->get('cron_enabled'),
      '#description' => $this->t('The denormalized views or tables will be updated incrementally on cron.'),
    ];

    $form['run_every'] = [
      '#title' => $this->t('Run every'),
      '#type' => 'textfield',
      '#default_value' => $config->get('run_every'),
      '#description' => $this->t('Time between runs.'),
    ];

    $form['reload_every'] = [
      '#title' => $this->t('Reload every'),
      '#type' => 'textfield',
      '#default_value' => $config->get('reload_every'),
      '#description' => t('Time between reloads.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('denormalizer.settings')
      ->setData($form_state->getValues())
      ->save();
    parent::submitForm($form, $form_state);
  }

}
